"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getInlineStylesheets = void 0;
// Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
// SPDX-License-Identifier: Apache-2.0
const theme_1 = require("../shared/theme");
const declaration_1 = require("../shared/declaration");
const mappings_1 = require("./mappings");
const utils_1 = require("../shared/utils");
const modules_1 = require("./tasks/postcss/modules");
/**
 * Generates a list of inline stylesheets used during the SCSS compilation. The primary
 * theme defines the mappings the environment.
 * @returns inline stylesheets
 */
function getInlineStylesheets(primary, secondary, resolution, variablesMap, propertiesMap, neededTokens) {
    const declarations = (0, declaration_1.createBuildDeclarations)(primary, secondary, propertiesMap, (selector) => (0, modules_1.markGlobal)(selector), neededTokens);
    const declaration = {
        url: 'awsui:globals',
        contents: declarations,
    };
    const tokens = (0, mappings_1.renderMappings)(resolution, variablesMap, propertiesMap);
    const mapping = {
        url: 'awsui:tokens',
        contents: tokens,
    };
    const resolvedTokens = {
        url: 'awsui:resolved-tokens',
        contents: `$resolved-tokens: [${[primary, ...secondary]
            .map((theme) => (0, utils_1.jsonToSass)({ selector: theme.selector, tokens: (0, theme_1.resolveTheme)(theme) }))
            .join(',\n')}];`,
    };
    return [declaration, mapping, resolvedTokens];
}
exports.getInlineStylesheets = getInlineStylesheets;
