import { buildStyles, InlineStylesheet, BuildStylesOptions } from './tasks/style';
import { Theme } from '../shared/theme';
export { buildStyles, InlineStylesheet, BuildStylesOptions };
export type Tasks = 'preset' | 'design-tokens';
export interface BuildThemedComponentsInternalParams {
    /** Primary theme used for generation of styles and scoped names */
    primary: Theme;
    /** List of exposed design tokens in the design tokens package */
    exposed: string[];
    /** List of themeable design tokens */
    themeable: string[];
    /** Map between design tokens and a variable name used in SCSS */
    variablesMap: Record<string, string>;
    /** Components directory to be used as output for component styling */
    componentsOutputDir: string;
    /** SCSS source code directory to be used during the styles generation */
    scssDir: string;
    /** Optional: List of secondary themes included in the root stylesheet */
    secondary?: Theme[];
    /** If set, will skip the specified tasks */
    skip?: Tasks[];
    /** Design token directory to be used as output for design token files. Required if task is not skipped. */
    designTokensOutputDir?: string;
    /** File name of the design token files with the endings ts.d., .js and .scss. Default: 'index' */
    designTokensFileName?: string;
    /** Map between design tokens and their description */
    descriptions?: Record<string, string>;
    /** Indicates whether to generate a JSON schema for design tokens JSON format and validate against the schema **/
    jsonSchema?: boolean;
    /** Fail the build when SASS deprecation warning occurs **/
    failOnDeprecations?: boolean;
}
/**
 * Builds themed components and optionally design tokens, if not skipped.
 *
 * The styles will be build with three inline stylesheets:
 * * `awsui:environment` - Stylesheet containing a simple environment context
 * * `awsui:globals` - Root stylesheet with custom property assignments
 * * `awsui:tokens`  - Mapping between SASS variables and var() assignments
 *
 * If designTokensOuputDir is specified and not skipped, three with designTokensFileName will be generated:
 * * Typescript
 * * Typescript definitions
 * * SCSS
 *
 * @param params build themed components parameters
 */
export declare function buildThemedComponentsInternal(params: BuildThemedComponentsInternalParams): Promise<void>;
