"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
// Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
// SPDX-License-Identifier: Apache-2.0
const fs_1 = __importDefault(require("fs"));
const glob_1 = __importDefault(require("glob"));
const flatten_1 = __importDefault(require("lodash/flatten"));
const uniq_1 = __importDefault(require("lodash/uniq"));
const findUsedSassVariablesInFile = (filePath, sassVariablesList) => {
    const content = fs_1.default.readFileSync(filePath, 'utf-8');
    return sassVariablesList.filter((sassVariable) => content.indexOf(`.$${sassVariable}`) > -1);
};
const findusedUsedSassVariablesInDir = (scssDir, sassVariablesList) => {
    const filePaths = glob_1.default.sync(`${scssDir}/**/*.scss`);
    const usedSassVariables = (0, uniq_1.default)((0, flatten_1.default)(filePaths.map((filePath) => findUsedSassVariablesInFile(filePath, sassVariablesList)))).sort();
    return usedSassVariables;
};
const findNeededTokens = (scssDir, variablesMap, exposed) => {
    const usedSassVariables = findusedUsedSassVariablesInDir(scssDir, Object.values(variablesMap));
    const usedTokens = Object.keys(variablesMap).filter((token) => usedSassVariables.indexOf(variablesMap[token]) !== -1);
    return (0, uniq_1.default)([...usedTokens, ...exposed]);
};
exports.default = findNeededTokens;
