"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.calculatePropertiesMap = void 0;
// Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
// SPDX-License-Identifier: Apache-2.0
const theme_1 = require("../shared/theme");
const token_1 = require("./token");
function calculatePropertiesMap(themes, variablesMap) {
    const resolutions = [];
    themes.forEach((theme) => {
        resolutions.push((0, theme_1.resolveTheme)(theme));
        Object.values(theme.contexts || {}).forEach((context) => {
            resolutions.push((0, theme_1.resolveContext)(theme, context));
        });
    });
    const tokensValuesMap = getTokensValuesFromResolutions(resolutions);
    const mapEntries = Object.entries(tokensValuesMap).map(([token, values]) => {
        return [token, (0, token_1.toCssVarName)(variablesMap[token], values.filter((value) => !!value))];
    });
    return Object.fromEntries(mapEntries);
}
exports.calculatePropertiesMap = calculatePropertiesMap;
const getTokensValuesFromResolutions = (resolutions) => resolutions.reduce((tokensValuesMap, resolution) => {
    Object.entries(resolution).forEach(([token, assignment]) => {
        const values = typeof assignment === 'string' ? [assignment] : Object.values(assignment);
        if (!tokensValuesMap[token]) {
            tokensValuesMap[token] = [];
        }
        tokensValuesMap[token] = [...tokensValuesMap[token], ...values];
    });
    return tokensValuesMap;
}, {});
