"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.buildThemedComponents = void 0;
// Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
// SPDX-License-Identifier: Apache-2.0
const utils_1 = require("../shared/utils");
const theme_1 = require("../shared/theme");
const properties_1 = require("./properties");
const internal_1 = require("./internal");
const theme_2 = require("../shared/theme");
const copy_1 = require("./tasks/copy");
const validate_1 = require("../shared/theme/validate");
async function buildThemedComponents(params) {
    const { componentsOutputDir, designTokensOutputDir, preset: originalPreset, designTokensTemplateDir, templateDir, scssDir, override, baseThemeId, } = params;
    const preset = createThemedPreset(originalPreset, override, baseThemeId);
    (0, copy_1.copyAllFiles)(templateDir, componentsOutputDir);
    if (designTokensTemplateDir) {
        (0, copy_1.copyAllFiles)(designTokensTemplateDir, designTokensOutputDir);
    }
    await (0, internal_1.buildThemedComponentsInternal)({
        primary: preset.theme,
        secondary: preset.secondary,
        exposed: preset.exposed,
        themeable: preset.themeable,
        variablesMap: preset.variablesMap,
        componentsOutputDir,
        designTokensOutputDir,
        scssDir,
        designTokensFileName: preset.theme.id,
    });
}
exports.buildThemedComponents = buildThemedComponents;
function createThemedPreset(preset, override, baseThemeId) {
    const theme = (0, validate_1.getThemeFromPreset)(preset, baseThemeId);
    const availableContexts = (0, validate_1.getContexts)(preset);
    const validated = (0, theme_2.validateOverride)(override, preset.themeable, availableContexts);
    const result = (0, theme_1.merge)(theme, validated);
    const newPreset = (0, utils_1.cloneDeep)(preset);
    if (newPreset.theme.id === theme.id) {
        newPreset.theme = result;
    }
    else {
        const themeIndex = (newPreset.secondary || []).findIndex((item) => item.id === theme.id);
        (newPreset.secondary || [])[themeIndex] = result;
    }
    const propertiesMap = (0, properties_1.calculatePropertiesMap)([newPreset.theme, ...(newPreset.secondary || [])], preset.variablesMap);
    newPreset.propertiesMap = propertiesMap;
    return newPreset;
}
