"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createRelativeScopedNameFunction = void 0;
// Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
// SPDX-License-Identifier: Apache-2.0
const path_1 = __importDefault(require("path"));
const string_hash_1 = __importDefault(require("string-hash"));
function toHash(value) {
    return (0, string_hash_1.default)(value).toString(36).substr(0, 5);
}
// The code of this function is based on the original version:
// https://github.com/css-modules/postcss-modules/blob/master/src/generateScopedName.js
// Our version also adds filename to the hash to handle such patterns:
// .root { /* used in test-utils */ }
// It should produce a different name in each file
function createRelativeScopedNameFunction(sourceDir) {
    return function generateScopedName(name, filename, css) {
        // The hash for the filename uses a relative path to avoid differences in absolute path
        // to change the module prefix. Further, it appends ./src to mimick the original path
        // in the monorepo.
        const filenameHash = toHash(path_1.default.join('src', path_1.default.relative(sourceDir, filename)));
        const contentHash = toHash(css);
        const index = css.indexOf(`.${name}`);
        const lineNumber = css.substr(0, index).split(/[\r\n]/).length;
        return `awsui_${name}_${filenameHash}_${contentHash}_${lineNumber}`;
    };
}
exports.createRelativeScopedNameFunction = createRelativeScopedNameFunction;
