"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.postCSSForEach = exports.postCSSAfterAll = exports.scopedFileExt = void 0;
// Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
// SPDX-License-Identifier: Apache-2.0
const autoprefixer_1 = __importDefault(require("autoprefixer"));
const path_1 = __importDefault(require("path"));
const postcss_1 = __importDefault(require("postcss"));
const postcss_discard_empty_1 = __importDefault(require("postcss-discard-empty"));
const postcss_inline_svg_1 = __importDefault(require("postcss-inline-svg"));
const postcss_modules_1 = __importDefault(require("postcss-modules"));
const increase_specifity_1 = __importDefault(require("./increase-specifity"));
const generate_scoped_name_1 = require("./generate-scoped-name");
const write_css_modules_1 = require("./write-css-modules");
exports.scopedFileExt = '.scoped.css';
// Temporarily hardcoded browserslist due to missing dependency
const browserslist = [
    'last 3 Chrome major versions',
    'last 3 Firefox major versions',
    'last 3 Edge major versions',
    'last 3 Safari versions',
];
const postCSSAfterAll = (input, filename) => {
    return (0, postcss_1.default)([
        (0, autoprefixer_1.default)({
            overrideBrowserslist: browserslist,
        }),
        (0, increase_specifity_1.default)(),
        (0, postcss_discard_empty_1.default)(),
    ]).process(input, { from: filename });
};
exports.postCSSAfterAll = postCSSAfterAll;
const postCSSForEach = (sourceDir, outputDir, input, filename) => {
    return (0, postcss_1.default)([
        // inline local svg before creating module
        (0, postcss_inline_svg_1.default)(),
        (0, postcss_modules_1.default)({
            generateScopedName: (0, generate_scoped_name_1.createRelativeScopedNameFunction)(sourceDir),
            getJSON(cssFileName, json) {
                (0, write_css_modules_1.writeCssModule)(path_1.default.relative(sourceDir, cssFileName), outputDir, exports.scopedFileExt, json);
            },
        }),
    ]).process(input, { from: filename });
};
exports.postCSSForEach = postCSSForEach;
