"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.renderCJSPresetDeclaration = exports.renderPresetDeclaration = exports.renderCJSPreset = exports.renderPreset = exports.createPresetFiles = void 0;
// Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
// SPDX-License-Identifier: Apache-2.0
const path_1 = require("path");
const utils_1 = require("../../shared/theme/utils");
const validate_1 = require("../../shared/theme/validate");
const file_1 = require("../file");
const generatedThemingDir = 'internal/generated/theming';
async function createPresetFiles(preset, outputDir) {
    const generatedDir = (0, path_1.join)(outputDir, generatedThemingDir);
    await Promise.all([
        (0, file_1.writeFile)((0, path_1.join)(generatedDir, '/index.js'), renderPreset(preset)),
        (0, file_1.writeFile)((0, path_1.join)(generatedDir, '/index.cjs'), renderCJSPreset(preset)),
        (0, file_1.writeFile)((0, path_1.join)(generatedDir, '/index.d.ts'), renderPresetDeclaration(preset)),
        (0, file_1.writeFile)((0, path_1.join)(generatedDir, '/index.cjs.d.ts'), renderCJSPresetDeclaration(preset)),
    ]);
}
exports.createPresetFiles = createPresetFiles;
function renderPreset(preset) {
    return `export var preset = ${JSON.stringify(preset, null, 2)};\n`;
}
exports.renderPreset = renderPreset;
function renderCJSPreset(preset) {
    return `module.exports.preset = ${JSON.stringify(preset, null, 2)};\n`;
}
exports.renderCJSPreset = renderCJSPreset;
function renderPresetDeclaration(preset) {
    return `import { ThemePreset, GlobalValue, TypedModeValueOverride } from '@cloudscape-design/theming-runtime';

export declare ${renderTypedOverrideInterface(preset)}
export declare const preset: ThemePreset;
`;
}
exports.renderPresetDeclaration = renderPresetDeclaration;
function renderCJSPresetDeclaration(preset) {
    return `import { ThemePreset, GlobalValue, TypedModeValueOverride } from '@cloudscape-design/theming-build';

export declare ${renderTypedOverrideInterface(preset)}
export declare const preset: ThemePreset;
`;
}
exports.renderCJSPresetDeclaration = renderCJSPresetDeclaration;
function renderTypedOverrideInterface(preset) {
    const tokens = preset.themeable.map((token) => {
        const mode = (0, utils_1.getMode)(preset.theme, token);
        if (mode) {
            const states = Object.keys(mode.states);
            return `${token}?: GlobalValue | TypedModeValueOverride<${states.map((state) => `'${state}'`).join(' | ')}>`;
        }
        else {
            return `${token}?: GlobalValue`;
        }
    });
    const contexts = (0, validate_1.getContexts)(preset).map((contextId) => {
        return `'${contextId}'?: {
      tokens: {
        ${tokens.join(';\n        ')};
      }
    }`;
    });
    return `interface TypedOverride {
  tokens: {
    ${tokens.join(';\n    ')};
  },
  contexts?: {
    ${contexts.join(';\n    ')}
  }
}`;
}
