"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.renderTS = exports.writeJSONfiles = exports.renderJS = exports.renderSCSS = exports.createPublicTokenFiles = void 0;
// Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
// SPDX-License-Identifier: Apache-2.0
const path_1 = require("path");
const file_1 = require("../file");
const token_1 = require("../token");
const theme_json_1 = require("./theme-json");
const theme_json_schema_1 = require("./theme-json-schema");
async function createPublicTokenFiles(params) {
    const { resolution, preset, outputDir, fileName, descriptions = {}, jsonSchema = false } = params;
    const { variablesMap, propertiesMap, exposed } = preset;
    await Promise.all([
        (0, file_1.writeFile)((0, path_1.join)(outputDir, `${fileName}.scss`), renderSCSS(resolution, variablesMap, propertiesMap, exposed)),
        (0, file_1.writeFile)((0, path_1.join)(outputDir, `${fileName}.js`), renderJS(resolution, propertiesMap, exposed)),
        (0, file_1.writeFile)((0, path_1.join)(outputDir, `${fileName}.d.ts`), renderTS(exposed)),
        writeJSONfiles(preset, outputDir, fileName, descriptions, jsonSchema),
    ]);
}
exports.createPublicTokenFiles = createPublicTokenFiles;
function renderSCSS(resolution, variablesMap, propertiesMap, tokens) {
    return tokens
        .map((token) => `${(0, token_1.toSassName)(variablesMap[token])}: var(${propertiesMap[token]}, ${resolution[token]});`)
        .join('\n');
}
exports.renderSCSS = renderSCSS;
function renderJS(resolution, propertiesMap, tokens) {
    return tokens
        .map((token) => `export var ${token} = "var(${propertiesMap[token]}, ${resolution[token]})";`)
        .join('\n');
}
exports.renderJS = renderJS;
async function writeJSONfiles(preset, outputDir, fileName, descriptions, jsonSchema) {
    const { theme, secondary = [], exposed, variablesMap } = preset;
    await Promise.all([theme, ...secondary].map(async (currentTheme) => {
        const fullFileName = `${fileName}-${currentTheme.id}`;
        const themeJson = (0, theme_json_1.getThemeJSON)({ theme: currentTheme, exposed, variablesMap, descriptions });
        await (0, file_1.writeFile)((0, path_1.join)(outputDir, `${fullFileName}.json`), JSON.stringify(themeJson, null, 2));
        if (jsonSchema) {
            const themeJsonSchema = (0, theme_json_schema_1.getThemeJSONSchema)(currentTheme);
            (0, theme_json_schema_1.validateJson)(themeJson, themeJsonSchema);
            await (0, file_1.writeFile)((0, path_1.join)(outputDir, `${fullFileName}-schema.json`), JSON.stringify(themeJsonSchema, null, 2));
        }
    }));
}
exports.writeJSONfiles = writeJSONfiles;
function renderTS(tokens) {
    return tokens.map((token) => `export const ${token}: string;`).join('\n');
}
exports.renderTS = renderTS;
