"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.buildStyles = void 0;
// Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
// SPDX-License-Identifier: Apache-2.0
const sass = __importStar(require("sass"));
const glob_1 = __importDefault(require("glob"));
const postcss_1 = require("./postcss");
const path_1 = __importDefault(require("path"));
const fs_1 = __importDefault(require("fs"));
const util_1 = require("util");
const url_1 = require("url");
async function buildStyles(sassDir, outputDir, inlines = [], options = {}) {
    const files = await (0, util_1.promisify)(glob_1.default)('**/styles.scss', { cwd: sassDir });
    const compiler = createCompiler(inlines, outputDir, sassDir, options);
    const promises = files.map((file) => compiler(file));
    await Promise.all(promises);
}
exports.buildStyles = buildStyles;
/**
 * Importer injects the inline stylesheets if the import url matches
 * @param inlines inline stylesheets
 * @returns custom importer
 */
function createImporter(inlines) {
    const importer = {
        canonicalize(url) {
            return inlines.find(({ url: inlineUrl }) => url === inlineUrl) ? new URL(url) : null;
        },
        load(canonicalUrl) {
            const inline = inlines.find(({ url: inlineUrl }) => canonicalUrl.toString() === inlineUrl);
            if (inline) {
                return {
                    contents: inline.contents,
                    syntax: 'scss',
                };
            }
            return null;
        },
    };
    return importer;
}
const npmImports = {
    findFileUrl(url) {
        if (url.startsWith('.') || url.startsWith('~')) {
            return null;
        }
        return new URL(`${(0, url_1.pathToFileURL)('node_modules')}/${url}`);
    },
};
function createCompiler(inlines, outputDir, sassDir, options) {
    const importer = createImporter(inlines);
    return async (file) => {
        const input = path_1.default.join(sassDir, file);
        const deprecations = [];
        const sassResult = sass.compile(input, {
            logger: {
                warn(message, meta) {
                    const fullMessage = [message, meta.stack].join('\n');
                    if (meta.deprecation && options.failOnDeprecations) {
                        deprecations.push(fullMessage);
                    }
                    else {
                        console.warn(fullMessage);
                    }
                },
            },
            style: 'expanded',
            importers: [importer, npmImports],
        });
        if (deprecations.length > 0) {
            for (const deprecation of deprecations) {
                console.error(deprecation);
            }
            throw new Error('Unexpected deprecation warnings during sass build.');
        }
        const intermediate = path_1.default.join(sassDir, rename(file, '.css'));
        const postCSSForEachResult = await (0, postcss_1.postCSSForEach)(sassDir, outputDir, sassResult.css, intermediate);
        const postCSSAfterAllResult = await (0, postcss_1.postCSSAfterAll)(postCSSForEachResult.css, intermediate);
        const output = path_1.default.join(outputDir, rename(file, postcss_1.scopedFileExt));
        await fs_1.default.promises.writeFile(output, postCSSAfterAllResult.css);
    };
}
const rename = (file, extension) => file.replace(/\.scss$/, extension);
