"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getThemeJSON = void 0;
// Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
// SPDX-License-Identifier: Apache-2.0
const theme_1 = require("../../shared/theme");
function getThemeJSON({ theme, ...params }) {
    return {
        tokens: getTokensJson({
            ...params,
            resolvedTokens: (0, theme_1.resolveTheme)(theme),
        }),
        contexts: Object.keys(theme.contexts || {}).reduce((subAcc, contextName) => {
            subAcc[contextName] = {
                tokens: getTokensJson({
                    ...params,
                    resolvedTokens: (0, theme_1.resolveContext)(theme, theme.contexts[contextName]),
                }),
            };
            return subAcc;
        }, {}),
    };
}
exports.getThemeJSON = getThemeJSON;
function getTokensJson({ resolvedTokens, exposed, variablesMap, descriptions = {}, }) {
    return exposed.reduce((tokens, tokenName) => {
        const tokenVariable = variablesMap[tokenName];
        tokens[tokenVariable] = {
            $value: resolvedTokens[tokenName],
        };
        if (descriptions[tokenName]) {
            tokens[tokenVariable].$description = descriptions[tokenName];
        }
        return tokens;
    }, {});
}
