"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createBuildDeclarations = exports.createOverrideDeclarations = void 0;
// Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
// SPDX-License-Identifier: Apache-2.0
const theme_1 = require("../theme");
const rule_1 = require("./rule");
const single_1 = require("./single");
const multi_1 = require("./multi");
const selector_1 = require("./selector");
const registry_1 = require("./registry");
const transformer_1 = require("./transformer");
const utils_1 = require("../utils");
function createMinimalTheme(base, override) {
    const minimalTheme = (0, utils_1.cloneDeep)(base);
    const contextTokens = new Set();
    (0, utils_1.values)(minimalTheme.contexts).forEach((context) => {
        Object.keys(context.tokens).forEach((key) => {
            if (!(key in override.tokens) && !(key in (override?.contexts?.[context.id]?.tokens ?? {}))) {
                delete context.tokens[key];
            }
            else {
                contextTokens.add(key);
            }
        });
    });
    Object.keys(minimalTheme.tokens).forEach((key) => {
        if (!contextTokens.has(key) && !(key in override.tokens)) {
            delete minimalTheme.tokens[key];
        }
    });
    return (0, theme_1.mergeInPlace)(minimalTheme, override);
}
function createOverrideDeclarations(base, override, propertiesMap, selectorCustomizer) {
    // create theme containing only modified tokens
    const minimalTheme = createMinimalTheme(base, override);
    const ruleCreator = new rule_1.RuleCreator(new selector_1.Selector(selectorCustomizer), new registry_1.AllPropertyRegistry(propertiesMap));
    const stylesheetCreator = new single_1.SingleThemeCreator(minimalTheme, ruleCreator, base);
    const stylesheet = stylesheetCreator.create();
    return stylesheet.toString();
}
exports.createOverrideDeclarations = createOverrideDeclarations;
function createBuildDeclarations(primary, secondary, propertiesMap, selectorCustomizer, used) {
    const ruleCreator = new rule_1.RuleCreator(new selector_1.Selector(selectorCustomizer), new registry_1.UsedPropertyRegistry(propertiesMap, used));
    const stylesheetCreator = new multi_1.MultiThemeCreator([primary, ...secondary], ruleCreator);
    const stylesheet = stylesheetCreator.create();
    const transformer = new transformer_1.MinimalTransformer();
    const minimal = transformer.transform(stylesheet);
    return minimal.toString();
}
exports.createBuildDeclarations = createBuildDeclarations;
