"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.SingleThemeCreator = void 0;
// Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
// SPDX-License-Identifier: Apache-2.0
const theme_1 = require("../theme");
const stylesheet_1 = __importDefault(require("./stylesheet"));
const abstract_1 = require("./abstract");
const utils_1 = require("./utils");
class SingleThemeCreator extends abstract_1.AbstractCreator {
    constructor(theme, ruleCreator, baseTheme) {
        super();
        this.theme = theme;
        this.baseTheme = baseTheme;
        this.resolution = (0, theme_1.resolveTheme)(theme, this.baseTheme);
        this.ruleCreator = ruleCreator;
    }
    create() {
        const stylesheet = new stylesheet_1.default();
        const defaults = (0, theme_1.reduce)(this.resolution, this.theme, (0, theme_1.defaultsReducer)(), this.baseTheme);
        const rootRule = this.ruleCreator.create({ global: [this.theme.selector] }, defaults);
        SingleThemeCreator.appendRuleToStylesheet(stylesheet, rootRule, []);
        SingleThemeCreator.forEachOptionalModeState(this.theme, (mode, state) => {
            const modeResolution = (0, theme_1.reduce)(this.resolution, this.theme, (0, theme_1.modeReducer)(mode, state), this.baseTheme);
            const stateDetails = mode.states[state];
            const modeRule = this.ruleCreator.create({ global: [this.theme.selector, stateDetails.selector], media: stateDetails.media }, modeResolution);
            SingleThemeCreator.appendRuleToStylesheet(stylesheet, modeRule, [rootRule]);
        });
        SingleThemeCreator.forEachContext(this.theme, (context) => {
            const contextResolution = (0, theme_1.reduce)((0, theme_1.resolveContext)(this.theme, context, this.baseTheme, this.resolution), this.theme, (0, theme_1.defaultsReducer)(), this.baseTheme);
            const contextRule = this.ruleCreator.create({ global: [this.theme.selector], local: [context.selector] }, contextResolution);
            SingleThemeCreator.appendRuleToStylesheet(stylesheet, contextRule, [rootRule]);
            const contextRule2 = this.ruleCreator.create({ global: [this.theme.selector, context.selector] }, contextResolution);
            SingleThemeCreator.appendRuleToStylesheet(stylesheet, contextRule2, [rootRule]);
        });
        SingleThemeCreator.forEachContextWithinOptionalModeState(this.theme, (context, mode, state) => {
            const contextResolution = (0, theme_1.reduce)((0, theme_1.resolveContext)(this.theme, context, this.baseTheme, this.resolution), this.theme, (0, theme_1.modeReducer)(mode, state), this.baseTheme);
            const stateDetails = mode.states[state];
            const contextAndModeRule = this.ruleCreator.create({ global: [this.theme.selector, stateDetails.selector], local: [context.selector], media: stateDetails.media }, contextResolution);
            const contextRule = stylesheet.findRule(this.ruleCreator.selectorFor({ global: [this.theme.selector], local: [context.selector] }));
            const modeRule = stylesheet.findRule(this.ruleCreator.selectorFor({
                global: [this.theme.selector, mode.states[state].selector],
            }));
            const contextRuleGlobal = stylesheet.findRule(this.ruleCreator.selectorFor({ global: [this.theme.selector, context.selector] }));
            SingleThemeCreator.appendRuleToStylesheet(stylesheet, contextAndModeRule, (0, utils_1.compact)([contextRule, modeRule, rootRule]));
            const contextRuleAndModeRuleGlobal = this.ruleCreator.create({ global: [this.theme.selector, stateDetails.selector, context.selector], media: stateDetails.media }, contextResolution);
            SingleThemeCreator.appendRuleToStylesheet(stylesheet, contextRuleAndModeRuleGlobal, (0, utils_1.compact)([contextRuleGlobal, modeRule, rootRule]));
        });
        return stylesheet;
    }
}
exports.SingleThemeCreator = SingleThemeCreator;
