"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MinimalTransformer = void 0;
// Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
// SPDX-License-Identifier: Apache-2.0
const utils_1 = require("../utils");
const stylesheet_1 = require("./stylesheet");
class MinimalTransformer {
    transform(stylesheet) {
        const rules = stylesheet.getAllRules();
        const rulesWithPath = rules.map((rule) => ({
            rule,
            path: stylesheet.getPath(rule),
        }));
        const sorted = rulesWithPath.sort(({ path: pathA }, { path: pathB }) => pathA.length - pathB.length);
        sorted.forEach(({ rule, path }) => {
            if (path.length === 0) {
                // Root rule nothing to see here.
                return;
            }
            const resolvedParent = {};
            for (let i = path.length - 1; i >= 0; i--) {
                const parent = path[i];
                const declarations = parent.getAllDeclarations();
                declarations.forEach((decl) => {
                    resolvedParent[decl.property] = decl.value;
                });
            }
            const ruleValue = rule.getAllDeclarations().reduce((acc, decl) => {
                acc[decl.property] = decl.value;
                return acc;
            }, {});
            const diff = difference(resolvedParent, ruleValue);
            rule.clear();
            (0, utils_1.entries)(diff).forEach(([property, value]) => rule.appendDeclaration(new stylesheet_1.Declaration(property, value)));
            if (rule.size() === 0) {
                stylesheet.removeRule(rule);
            }
        });
        return stylesheet;
    }
}
exports.MinimalTransformer = MinimalTransformer;
function difference(mapA, mapB) {
    const diff = {};
    Object.keys(mapA).forEach((key) => {
        if (mapA[key] !== mapB[key] && mapB[key] !== undefined) {
            diff[key] = mapB[key];
        }
    });
    Object.keys(mapB).forEach((key) => {
        if (mapA[key] !== mapB[key] && mapB[key] !== undefined) {
            diff[key] = mapB[key];
        }
    });
    return diff;
}
