"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.increaseSpecificityGradually = exports.isGlobalSelector = exports.globalSelectors = exports.isIncreased = exports.increaseSpecificity = void 0;
// Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
// SPDX-License-Identifier: Apache-2.0
const utils_1 = require("../utils");
// The idea to use a special :not(#\9) selector to increase CSS specificity came from:
// https://github.com/MadLittleMods/postcss-increase-specificity
const specificitySuffix = ':not(#\\9)';
function increaseSpecificity(selector) {
    const [main, ...pseudo] = selector.split(':');
    const pseudoSuffix = pseudo.length ? ':' + pseudo.join(':') : '';
    return `${main}${specificitySuffix}${pseudoSuffix}`;
}
exports.increaseSpecificity = increaseSpecificity;
const isIncreased = (selector) => (0, utils_1.includes)(selector, specificitySuffix);
exports.isIncreased = isIncreased;
exports.globalSelectors = [':root', 'body', 'html'];
const isGlobalSelector = (selector) => exports.globalSelectors.indexOf(selector) > -1;
exports.isGlobalSelector = isGlobalSelector;
/**
 * Detects and repeats class names to increase specificity, otherwise
 * fall back to increase by id
 * @param selectors
 * @returns
 */
function increaseSpecificityGradually(selectors) {
    const split = selectors.split(',').map(repeatClassNameOrAddID);
    return split.join(',');
}
exports.increaseSpecificityGradually = increaseSpecificityGradually;
function repeatClassNameOrAddID(selector) {
    const result = /[:.][\w_-]+/.exec(selector);
    // exec without g flag will return max one match
    if (result?.length === 1) {
        const [match] = result;
        const { index } = result;
        return `${selector.substring(0, index)}${match}${selector.substring(index)}`;
    }
    return increaseSpecificity(selector);
}
