"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.merge = exports.mergeInPlace = void 0;
const utils_1 = require("../utils");
const utils_2 = require("./utils");
/**
 * This function applies all tokens from the override to the theme.
 * It returns the resulting theme. The original theme object is modified.
 */
function mergeInPlace(theme, override) {
    function withTokenApplied(originalValue, token, update) {
        const isGlobal = (0, utils_2.isValue)(update) || (0, utils_2.isReference)(update);
        const mode = (0, utils_2.getMode)(theme, token);
        if (mode && isGlobal) {
            return Object.keys(mode.states).reduce((acc, state) => {
                acc[state] = update;
                return acc;
            }, {});
        }
        else if (((0, utils_2.isModeValue)(originalValue) || originalValue === undefined) && (0, utils_2.isModeValue)(update)) {
            return {
                ...originalValue,
                ...update,
            };
        }
        else if (isGlobal) {
            return update;
        }
        else {
            console.warn('The value for this token cannot be merged into the theme:', token);
        }
    }
    // Merge root-level tokens into the theme
    (0, utils_1.entries)(override.tokens).forEach(([token, update]) => {
        const newValue = withTokenApplied(theme.tokens[token], token, update);
        if (newValue) {
            theme.tokens[token] = newValue;
        }
    });
    // Merge context-specific tokens into each context
    if (override.contexts) {
        (0, utils_1.entries)(override.contexts).forEach(([contextId, context]) => {
            const themeContext = theme.contexts[contextId];
            if (!context || !themeContext) {
                return;
            }
            (0, utils_1.entries)(context.tokens).forEach(([token, update]) => {
                const originalValue = themeContext.tokens[token] ?? theme.tokens[token];
                const newValue = withTokenApplied(originalValue, token, update);
                if (newValue) {
                    theme.contexts[contextId].tokens[token] = newValue;
                }
            });
        });
    }
    return theme;
}
exports.mergeInPlace = mergeInPlace;
/**
 * This function applies all tokens from the override to the theme.
 * It returns the resulting theme. The original theme object is not
 * modified.
 */
function merge(theme, override) {
    const result = (0, utils_1.cloneDeep)(theme);
    return mergeInPlace(result, override);
}
exports.merge = merge;
