"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getDefaultState = exports.getMode = exports.getReference = exports.isOptionalState = exports.areAssignmentsEqual = exports.isModeValue = exports.isReference = exports.isValue = void 0;
function isValue(val) {
    return typeof val === 'string' && !isReference(val);
}
exports.isValue = isValue;
function isReference(val) {
    return typeof val === 'string' && val.charAt(0) === '{' && val.charAt(val.length - 1) === '}';
}
exports.isReference = isReference;
function isModeValue(val) {
    return (typeof val === 'object' &&
        val !== null &&
        !Object.keys(val).some((state) => !(isValue(val[state]) || isReference(val[state]))));
}
exports.isModeValue = isModeValue;
function areAssignmentsEqual(valueA, valueB) {
    return (valueA === valueB ||
        (typeof valueA === 'object' &&
            typeof valueB == 'object' &&
            Object.keys(valueA).length === Object.keys(valueB).length &&
            Object.keys(valueA).every((key) => valueA[key] === valueB[key])));
}
exports.areAssignmentsEqual = areAssignmentsEqual;
function isOptionalState(val) {
    return 'selector' in val;
}
exports.isOptionalState = isOptionalState;
function getReference(reference) {
    return reference.slice(1, reference.length - 1);
}
exports.getReference = getReference;
function getMode(theme, token) {
    const modeId = theme.tokenModeMap[token];
    return theme.modes[modeId] ?? null;
}
exports.getMode = getMode;
function getDefaultState(mode) {
    const states = Object.keys(mode.states);
    for (let index = 0; index < states.length; index++) {
        const state = states[index];
        const option = mode.states[state];
        if (option && 'default' in option && option.default) {
            return state;
        }
    }
    throw new Error(`Mode ${JSON.stringify(mode)} does not have a default state`);
}
exports.getDefaultState = getDefaultState;
